==> kubernetes-model-apiextensions-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceSubresourceScaleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class CustomResourceSubresourceScaleFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<A>{
  public CustomResourceSubresourceScaleFluentImpl() {
  }
  public CustomResourceSubresourceScaleFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance) {
    this.withLabelSelectorPath(instance.getLabelSelectorPath()); 
    this.withSpecReplicasPath(instance.getSpecReplicasPath()); 
    this.withStatusReplicasPath(instance.getStatusReplicasPath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String labelSelectorPath;
  private java.lang.String specReplicasPath;
  private java.lang.String statusReplicasPath;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLabelSelectorPath() {
    return this.labelSelectorPath;
  }
  public A withLabelSelectorPath(java.lang.String labelSelectorPath) {
    this.labelSelectorPath=labelSelectorPath; return (A) this;
  }
  public java.lang.Boolean hasLabelSelectorPath() {
    return this.labelSelectorPath != null;
  }
  
  /**
   * Method is deprecated. use withLabelSelectorPath instead.
   */
  @java.lang.Deprecated
  public A withNewLabelSelectorPath(java.lang.String arg0) {
    return (A)withLabelSelectorPath(new String(arg0));
  }
  public java.lang.String getSpecReplicasPath() {
    return this.specReplicasPath;
  }
  public A withSpecReplicasPath(java.lang.String specReplicasPath) {
    this.specReplicasPath=specReplicasPath; return (A) this;
  }
  public java.lang.Boolean hasSpecReplicasPath() {
    return this.specReplicasPath != null;
  }
  
  /**
   * Method is deprecated. use withSpecReplicasPath instead.
   */
  @java.lang.Deprecated
  public A withNewSpecReplicasPath(java.lang.String arg0) {
    return (A)withSpecReplicasPath(new String(arg0));
  }
  public java.lang.String getStatusReplicasPath() {
    return this.statusReplicasPath;
  }
  public A withStatusReplicasPath(java.lang.String statusReplicasPath) {
    this.statusReplicasPath=statusReplicasPath; return (A) this;
  }
  public java.lang.Boolean hasStatusReplicasPath() {
    return this.statusReplicasPath != null;
  }
  
  /**
   * Method is deprecated. use withStatusReplicasPath instead.
   */
  @java.lang.Deprecated
  public A withNewStatusReplicasPath(java.lang.String arg0) {
    return (A)withStatusReplicasPath(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceSubresourceScaleFluentImpl that = (CustomResourceSubresourceScaleFluentImpl) o;
    if (labelSelectorPath != null ? !labelSelectorPath.equals(that.labelSelectorPath) :that.labelSelectorPath != null) return false;
    if (specReplicasPath != null ? !specReplicasPath.equals(that.specReplicasPath) :that.specReplicasPath != null) return false;
    if (statusReplicasPath != null ? !statusReplicasPath.equals(that.statusReplicasPath) :that.statusReplicasPath != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labelSelectorPath,  specReplicasPath,  statusReplicasPath,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceSubresourceScaleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class CustomResourceSubresourceScaleFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScaleFluent<A>{
  public CustomResourceSubresourceScaleFluentImpl() {
  }
  public CustomResourceSubresourceScaleFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceSubresourceScale instance) {
    this.withLabelSelectorPath(instance.getLabelSelectorPath()); 
    this.withSpecReplicasPath(instance.getSpecReplicasPath()); 
    this.withStatusReplicasPath(instance.getStatusReplicasPath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String labelSelectorPath;
  private java.lang.String specReplicasPath;
  private java.lang.String statusReplicasPath;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getLabelSelectorPath() {
    return this.labelSelectorPath;
  }
  public A withLabelSelectorPath(java.lang.String labelSelectorPath) {
    this.labelSelectorPath=labelSelectorPath; return (A) this;
  }
  public java.lang.Boolean hasLabelSelectorPath() {
    return this.labelSelectorPath != null;
  }
  
  /**
   * Method is deprecated. use withLabelSelectorPath instead.
   */
  @java.lang.Deprecated
  public A withNewLabelSelectorPath(java.lang.String arg0) {
    return (A)withLabelSelectorPath(new String(arg0));
  }
  public java.lang.String getSpecReplicasPath() {
    return this.specReplicasPath;
  }
  public A withSpecReplicasPath(java.lang.String specReplicasPath) {
    this.specReplicasPath=specReplicasPath; return (A) this;
  }
  public java.lang.Boolean hasSpecReplicasPath() {
    return this.specReplicasPath != null;
  }
  
  /**
   * Method is deprecated. use withSpecReplicasPath instead.
   */
  @java.lang.Deprecated
  public A withNewSpecReplicasPath(java.lang.String arg0) {
    return (A)withSpecReplicasPath(new String(arg0));
  }
  public java.lang.String getStatusReplicasPath() {
    return this.statusReplicasPath;
  }
  public A withStatusReplicasPath(java.lang.String statusReplicasPath) {
    this.statusReplicasPath=statusReplicasPath; return (A) this;
  }
  public java.lang.Boolean hasStatusReplicasPath() {
    return this.statusReplicasPath != null;
  }
  
  /**
   * Method is deprecated. use withStatusReplicasPath instead.
   */
  @java.lang.Deprecated
  public A withNewStatusReplicasPath(java.lang.String arg0) {
    return (A)withStatusReplicasPath(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceSubresourceScaleFluentImpl that = (CustomResourceSubresourceScaleFluentImpl) o;
    if (labelSelectorPath != null ? !labelSelectorPath.equals(that.labelSelectorPath) :that.labelSelectorPath != null) return false;
    if (specReplicasPath != null ? !specReplicasPath.equals(that.specReplicasPath) :that.specReplicasPath != null) return false;
    if (statusReplicasPath != null ? !statusReplicasPath.equals(that.statusReplicasPath) :that.statusReplicasPath != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(labelSelectorPath,  specReplicasPath,  statusReplicasPath,  additionalProperties,  super.hashCode());
  }
  
}
